HEIDI:
Previously on Project Runway...
We will be giving
each of you $10,000
to create ten-look collections.
TIM:
But only three of you
are guaranteed a spot
at Fashion Week.
Oh, my gosh.
HEIDI: Designers, this is a time
to really bring it.
-These prints are smashing.
-Thanks.
You are on a great course,
-and I’m crazy about it.
-[chuckles]
AYANA: I wanted my collection
to be very earthy.
-You need to work hard, and you
need to work smart. -Yes.
TIM:
I am underwhelmed by the colors.
This palette is just going
to be a snooze fest.
You did not want it
to look cohesive?
-I will get bored.
-You really do have
three different
collections here.
♪ ♪
HEIDI: Ayana, Brandon,
you’re moving forward
-to New York Fashion Week.
-Thank you!
Margarita, you are also moving
to New York Fashion Week.
Kentaro, Kenya,
one of you will be out.
Kentaro, congratulations.
Kenya, I’m so sorry. You’re out.
♪ ♪
Oy.
Cohesion, cohesion, cohesion.
MARGARITA: The judges said
that it’s resorty.
I’m like, "Yeah, duh."
That’s me.
You want my aesthetic?
It’s tropical. You can take
the girl out of the tropics,
but you can’t take the tropics
out of the girl.
You know what I mean?
I’ve put my everything
into Project Runway.
I mean, I quit my job.
So I’m putting everything
on the line
for a really big win.
BRANDON:
I feel good. I feel like I did
what I needed to back home.
I feel prepared.
I feel confident.
I’m ready to win the whole
thing. I’m ready.
MARGARITA:
I can’t focus.
My mind’s somewhere else.
I’m thinking about Puerto Rico.
There’s a massive hurricane
on its way to hit the island,
and I’m scared.
-AYANA: Hi, Tim!
-Hi.
I’m here to check in with you.
All right?
-Margarita, first things first.
-Hi.
We’re with you in spirit
and with your family, too,
and thinking
only positive thoughts.
How are you feeling
about all this?
-Mixed.
-Yeah, I’m sure.
It’s like,
I have all this other stuff
on my mind,
but then there’s that.
-It’s a lot to be processing
at the moment. -Yeah.
But on a lighter note...
Your collection!
After that critique,
I feel confused.
The print’s on that cusp
of being hideous.
You have to make sure also
that the whole thing
doesn’t look too tropical.
I mean, I’m from Puerto Rico.
My name is Margarita.
-Like, it’s how I feel.
-This is a customer
who would wear each and every
one of these looks.
That’s how I feel, too.
-And also, like, I stand by it.
-Right.
-And I stand with you strongly.
-Okay.
-Carry on.
-Will do.
Thank you, Margarita.
Thank you.
-Ayana.
-Hi.
So, what did you hear
the judges say?
They kind of talked
about me styling
with the head wraps,
instead of just, like,
a simple wrap, like kind of
like what I’ve been doing.
What are you going to do
about the head wraps?
Well, I think they maybe want
something that’s
-a little bit more showy.
-I’m very confident.
-Okay. I feel good.
-You should.
-All right.
-Thank you, Tim.
-TIM: Kentaro, hi.
-Hi.
What did you hear
the judges say?
It wasn’t cohesive.
-And you knew that.
-Yes.
And how are you responding
to that?
So this is a top I made
for this one,
and I brought it here
to start this collection
black and white.
And sort of, like, I kind of
wanted to do white at the end.
-Okay. -Kind of like sweeping
away everything I have done.
I was going to make
something new, to make it work.
Well, you still have
a lot of fittings.
-Fitting is going to be okay.
-All right.
-Yeah, I believe. Yeah. Yeah.
-I’m glad you’re confident.
-Brandon, how are you doing?
-I’m doing good.
What did you take away
from the judges’ critique?
Get rid of the top for Liris.
I do not care for this top.
It really jumps out because
everything else is so crisp,
and this feels
-like a throwaway look.
-BRANDON: And I agreed.
You know, I didn’t think it
was the most flattering.
And then, I mean, the rest...
I feel... I feel good.
I feel confident.
It’s just... it’s just really
about this fitting,
getting them in here, and, uh...
I feel like I’ll work my magic
once they’re...
TIM: Well, you constantly do.
That’s for sure.
-Thank you, Brandon.
-Thank you.
All right, designers, my advice
to each of you is the same.
Stay on your path.
All right?
I will see you tomorrow.
-BRANDON: All right, Tim.
-All right. Thank you.
-Thank you.
-Thank you, Tim. -Thank you.
♪ ♪
HEIDI:
Coming up on Project Runway...
[cheering and applause]
Absolutely stunning.
Wow, this is beautiful.
-I am incredibly impressed.
-Hallelujah.
All of you put on a great show,
but only one of you
will be the winner
of Project Runway season 16.
♪ ♪
BRANDON:
Oh, goodness.
MARGARITA:
I love how they told me
to edit myself, right? Like...
-All I want to do is add
more stuff. -[Ayana laughs]
I want to put feathers
and fringe.
Didn’t Tim say to, like, own it?
MARGARITA:
That’s what I’m saying!
-Hi, cuties.
-Hey, hey, hey.
Gentle. Gentle.
Hand-beaded. They might fall.
BRANDON:
How do you feel?
I think it’s...
it does look better.
I feel like Brandon
has a cohesive collection.
The only thing that I’m
a little worried about is--
does he have a wow moment?
Mmm, it’s up to you.
It’s your collection.
[laughs]
KENTARO:
Whoa.
I like how this dress
makes sound.
AYANA:
Meisha.
-Yes. -Okay, let’s get you
in shoes first.
And then we’ll get you
in your look.
AYANA: I thought
it would be pretty awesome
to have you close the show.
Tim is all about the...
It’s Project Runway.
We should have a runway moment.
Whoo!
Mm-hmm. Yeah. I love it.
BRANDON:
My vibes are good.
You know, I’m definitely
in a good spot, and it’s...
been a hell of an experience
here at Project Runway.
HEIDI:
Congratulations.
You are the clear winner
of this challenge.
You are the winner
of this challenge.
Congratulations. You are
the winner of this challenge.
Thank you so much.
It feels amazing.
I love that smile on your face.
BRANDON:
Winning time after time,
it helped me. It helped me
build my confidence.
And I know my aesthetic,
and I...
and I’ve stayed true
to that, so...
I’m just thankful
for everything,
and-and it’s gonna be great.
[yawning]
I’ll just work one by one
through it.
Ayana, how are you doing
time-wise? Are you thinking...
Um, actually, I feel like
I’m doing pretty good.
I’m just trying
to make it look better.
KENTARO:
Ayana’s look is
very cohesive.
I think this is what Tim
wanted me to do,
then I didn’t do it.
Again, I feel like
I’m losing.
♪ ♪
BRANDON: Did your family
make it out, Margarita?
MARGARITA:
I don’t know.
They didn’t have power
yesterday.
I mean, the power’s cut off.
It’ll probably take
like four months.
[gasps]
I’m just trying to keep it
together and not lose it,
’cause I feel at peace
with what I’ve done.
MARGARITA:
And I don’t think I would
change this experience
for anything else in the world.
Super cute!
-Hi, everyone.
-Hi, Tim. -Hi, Tim. -Hey.
TIM:
Something occurred to me.
I don’t think we’ve had a single
gather-round
in this entire season,
but we’re going to have one now.
Everyone gather round.
This is an important,
big moment.
I just want you all to know
how proud I am
of each and every one of you.
You should feel so fantastically
proud of what you’ve achieved,
and just know that in the end,
it’s going to be
a matter of taste
with the judges.
And we have absolutely
no control over that,
and that’s the way
that we want it.
Let’s have a group hug.
AYANA: Throughout my
Project Runway experience,
I feel like Tim
really pushed me
to be my best self.
All for one, one for all.
-Yay, Project Runway!
-Yeah! -Yay!
I will see you dark and early
in the morning.
Pack up. Get some rest.
-I love you all. Take care.
-Love you, Tim.
MARGARITA:
This is it. It’s the last day.
A lot of blood, sweat
and tears up in this room.
AYANA:
All right, we gotta go.
We have early morning
and all that good stuff.
Big day tomorrow.
MARGARITA: I, like, really want
to wake up every day
and love what I do,
and do what I love.
Winning Project Runway
will just solidify that
possibility.
It would change my life.
♪ ♪
AYANA:
Good morning.
-Good morning.
-Good morning.
-AYANA: Are you guys excited?
-I’m so excited.
MARGARITA: I couldn’t sleep,
like Christmas.
I know.
I struggled to sleep, too.
Winning Project Runway
would be just amazing.
It would validate me
as a designer
and the clothes
I like to make, and...
it would mean the world.
AYANA:
Good luck, everybody.
KENTARO: Showing my collection
at New York Fashion Week
is, like, beyond my dream.
But now
I’m doing it, so...
I’m super happy.
[gasping, laughing]
AYANA:
Oh, my gosh!
-Let’s do it.
-KENTARO: Let’s do it!
BRANDON:
Let’s get to work.
[indistinct chatter]
KENTARO:
Hey, everybody!
MARGARITA:
Did you see the runway?
-No, I haven’t seen it.
-Oh, my God!
BRANDON:
Backstage is crazy.
It’s nuts. It’s too much.
-For the braids, like, can we
just have it forward? -Sure.
MARGARITA:
There’s like 55 people
doing hair and makeup,
models everywhere.
A lot of moving parts
happening back here.
[indistinct chatter]
AYANA:
Yeah, I’m ready.
I’m happy that the judges
encouraged me to do this,
’cause it’s kind of fun.
If I can nail
my hijab styles,
I feel like I have a really,
really strong shot
at winning.
Gotta move a little bit faster.
♪ ♪
Designers, you have one hour.
-My steamer’s not working.
-These irons. What is this?
We’re all like,
"What the [bleep]?"
We keep blowing the fuses.
Hello!
Okay, hold it there.
I feel very good.
I’m not stressed out.
Ooh, pockets!
KENTARO:
It is a heavenly situation.
No problem at all.
You guys look beautiful!
[indistinct chatter]
Five minutes, everyone.
Five minutes.
BRANDON: Is it too tight still?
Are you all right?
-I feel good. It’s good now.
-Okay.
BRANDON:
The only reason why
I came on this show was to win,
and I felt I could
from the beginning, so...
I’m gonna win.
♪ ♪
WOMAN:
Stand by for judges.
MAN:
Here we go. And...
walking out.
WOMAN:
And action, judges.
[cheering and applause]
♪ ♪
HEIDI:
Coming up on Project Runway...
-Bravo.
-It was a very powerful show.
Wow, this is beautiful.
What is this?
What’s gonna happen now?
♪ ♪
MAN:
Here we go, and... walking out.
[cheering and applause]
Hello, everybody.
Welcome to season 16
of Project Runway.
[cheering and applause]
We’re celebrating our sweet 16,
and we are very, very excited.
We’re also celebrating models
of all sizes
for the very first time.
-[cheering]
-Yes.
Because fashion is for everyone.
Now I would like
to introduce to you
our Project Runway judges.
We have Zac Posen.
[cheering and applause]
The lovely Nina Garcia.
[cheering and applause]
And our special guest judge
for today,
-the beautiful Jessica Alba.
-[cheering and applause]
However it’s falling...
-Leave it.
-Yeah. Let it...
Natural. Nothing forced.
My heart’s beating
out of my chest.
I’m nervous, but, like,
excited nervous energy.
This just solidifies all
the effort, all the sacrifices.
And being here
just makes all of that worth it.
I can’t wait to see
what our amazing designers
have created for all of you.
Enjoy the show, everyone.
Thank you so much
for coming today.
[cheering and applause]
Hi, everybody.
The title of my collection
is called "A Fish Out of Water."
And it tells the story of an
island girl living in the city,
leaving her home
and living a new life.
I want to dedicate
this collection to my family,
the Alvarez,
and to my beautiful Puerto Rico.
Enjoy.
[cheering, whistling]
♪ ♪
TIM:
Knock ’em dead
from the very beginning.
MARGARITA: I’m just beyond happy
with what I came up with,
and I think it’s just gonna
make everybody smile.
♪ ♪
TIM:
Here she comes.
Yes, queen!
♪ ♪
[cheering]
-Fab.
-Big runway moment!
[applause]
MARGARITA: I want to be
the next Carolina Herrera.
I want to be the next
Oscar de la Renta.
Latin American designers are
known to be really talented,
and I just want
to continue that legacy.
I’m really, really happy
that I didn’t give up
and that I came out
g*ns blazing
and showed a...
a fantastic collection
that every single woman
would want to wear.
You put on a show.
Thank you.
That’s what I wanted.
And you did.
[cheering and applause]
WOMAN; Brandon?
Hey, Brandon, five minutes.
Five minutes?
I feel a little bit
of everything. There’s stress.
There’s nerves. I’m anxious.
But I love it, you know?
I love to push myself, and this
is what I’m meant to do,
so I’m up for it.
[cheering and applause]
Thank you for coming.
My name is Brandon Kee.
The collection’s called
"Layers of Love,"
and I hope you enjoy.
Thank you.
[cheering and applause]
♪ ♪
BRANDON:
I feel like it shows variety.
I got a wide range of ethnicity
in girls and hair styles,
but I kept it natural
and a bit minimum
and let the clothes
speak for themselves.
It demonstrates so clearly
that you can take
a fairly limited range
of materials
and come up with something
fresh and new
-with each and every look.
-BRANDON: Thank you, Tim.
♪ ♪
Ah, I love that leather.
I really focused
on the pieces individually.
Each piece, I wanted
to be a standout piece.
But at the same time,
the juxtaposition
of putting all those unique
pieces in the same fabric,
to me, just something
about that is beautiful.
I think I have
the winning collection.
[cheering and applause]
KENTARO:
I already have things to say.
"Hi, everybody."
Oh, [bleep].
English not my first language,
so I get nervous
because I’m not good
at talking in front
of people, so...
I kind of practice a little bit.
My special, as Ja...
uh, Japan... Oh.
-[cheering and applause]
-Hi.
My name’s Kentaro.
Uh, thank you for coming.
Um, my collection was inspired
by my Japanese culture,
and you’re going to see a lot
of beautiful image of Japan.
And also, I composed and played
the music you will hear,
so I hope you will enjoy.
Thank you so much.
[cheering]
[stark piano music plays]
KENTARO:
Music is very important because
what I want to do most
is conveying emotion
throughout my show.
So, if I make
something emotional,
people is gonna be emotional.
♪ ♪
This is the new piece.
-Oh, you made that yesterday?
-Mm-hmm.
♪ ♪
♪ ♪
KENTARO: I don’t feel like this
is competition at this point.
No pressure.
No winning, no losing.
The most important thing for me
is being able to show
something beautiful.
And I did my best,
so no regret.
[cheering and applause]
Do not stop when you enter.
All right, so let’s move up.
Let’s move up.
AYANA:
Good luck. Make me proud.
Just months ago, I was
wishing I could show
at New York Fashion Week.
I remember people sharing on
social media, like, "Hey, girl.
One day, you know?
That’s gonna be you."
And, like, today’s that day.
[cheering and applause]
Hi, everybody.
My collection is titled
"Evolution."
It documents
a personal journey of mine.
When I was at my lower point
and, uh, just kind of
pushing through
and staying the course.
And please enjoy.
-Thank you.
-[cheering and applause]
♪ ♪
AYANA:
Oh, my gosh.
[crying]
Aw.
AYANA: Watching the collection
on screen with Tim,
it just seems
like it’s not real,
like this is not
really happening.
This is everything
that I want in this moment.
TIM:
That one’s spectacular.
-Thank you, Tim.
-It’s not just really good.
♪ ♪
AYANA:
I’m so proud of everything.
I said I was gonna do it,
and I did it,
and I’m just so happy that
I was given this opportunity.
Oh, my God.
It is spectacular.
[cheering and applause]
I thought it was extraordinary.
I mean, not that I
only love to see
all the designers express
themselves, but for me,
the most heartwarming part
was seeing
women of all sizes.
-I love you, honey.
-ANNE: I think one of my
favorite moments
was actually when the model
took off her sarong and walked
the bathing suit
all the way up. Fabulous.
KATHERINE: Margarita’s
really took it away.
Everything moved beautifully
on body.
So vibrant, so dynamic.
Blew me away.
[squeals] I’m gonna cry.
I loved Ayana.
So powerful and dynamic.
A really modern representation
of women in Islam today.
BRANDON:
Thank you, Mom. I love you.
I loved all the flamingo print.
It was a lot,
but individually, each piece,
I would 100% wear.
Ah! My parents!
Oh, my God, I love them.
Oh, my gosh!
Jazzmine.
-That was a great show.
-Incredible.
All right, let’s bring out
our designers.
Yay!
How amazing was today?
[chuckling]:
It was awesome.
It was good.
Just... I’m so happy.
I feel a little bit emotional.
-[laughs]
-HEIDI: All right,
let’s say hello to our judges.
First, we have creative director
of Brooks Brothers Women
and fashion designer, Zac Posen.
Hi, designers. You did such
a spectacular job today.
I think each of you
brought something
really personable. Bravo.
Creative director for Marie
Claire magazine, Nina Garcia.
Congratulations, team.
I feel very proud of each
and every one of you.
And our guest judge for today,
actress and founder of the
Honest Company, Jessica Alba.
Hi, everyone.
Your individuality
really just shined.
And also being able
to elevate it
and celebrate women
of all sizes, it was...
it was really cool.
Before we decide
who will be the winner
of Project Runway season 16,
we have some questions for you.
Ayana, let’s bring out
your models.
Wow.
Ayana, tell us about
your inspiration
and your collection.
I wanted it to be a very
emotional,
kind of moody type of show.
And so I mixed with a lot
of the ruffles that I like to do
distressing of denim,
dying fabrics,
and also incorporate the
modesty aspect of my designs.
What you have in front of us
is absolutely stunning.
This gown really brought
the drama today.
HEIDI: I mean, it was stunning,
breathtaking.
-You looked so beautiful
in this dress. -Thank you.
You convinced me
that there’s a way
to dress in forms of modesty,
in respect to one’s
religious background
and still be hip and seductive,
and I think
you’re representing
a whole community
around the world beautifully,
and I-I’m beyond proud of you.
Thank you.
I love your collection.
I wish I would have seen
a little color,
but I am incredibly impressed.
You had...
the athleticwear.
Then you had
a kind of streetwear.
And then this
very precious finale.
So that is not an easy feat
with just ten pieces.
The tailoring was beautiful.
You showed a little ankle
and a little wrist
here and there.
It was very subtle,
but it was sensual.
-Thank you. -It took my breath
away. It’s gorgeous.
Thank you.
Margarita, tell us
about your collection.
Well, my inspiration came
from my culture, and I thought,
what better way
of making a collection
to design my own print
and kind of show the world
who I am.
Your collection had so much
energy, passion, color.
ZAC:
It was really...
spectacular. It was joyous.
I think this is clothing
that could be bought.
It could even be its own
little boutique in itself.
-I’m very proud of you.
-Thank you.
NINA:
I thought you were very smart
when you picked your model
to have a moment
on the runway. We heard
this incredible applause,
and people were so exhilarated
-and happy to see that.
-I think it was
a very important moment
in fashion, too, right?
-That just said it all.
-Yeah.
k*lled it, girlfriend.
Kentaro, tell us
about your collection.
My whole collection
was about story,
music, sound, feeling
and Japanese culture.
Kudos to you.
I knew you had it in you.
But I think you
surprised us all.
The first look
was incredibly dramatic.
And the line continued.
You went from that
black and white into the nude,
and then all of a sudden
surprised us
with that shock of the color.
-ZAC: Camellia red.
-What a red.
I totally agree with Nina.
I had one piece,
the second red dress--
to me, it’s like
that strike of red
could have been just one note
of the music,
and then to the next.
-I didn’t mind it.
-I loved it.
-They loved it.
-I loved it, too, because
there are so many
different silhouettes
that just came coming,
and you’re like,
"Wow, exciting, wow."
I just had trouble with the two
next to each other.
I was eating it up
from the beginning to the end.
You blew my socks off today.
Just the evolution
of texture and color
and experimentation.
Really excellent,
excellent collection.
-Like nothing we’ve ever seen
on the show. -Thank you.
Brandon, tell us
about your collection.
I call this collection
"Layers of Love,"
and it was inspired
by my girlfriend, Dina.
So I found this
home furnishing fabric,
and it was like a sunshade,
patio furniture
that I was able to, like, dye
and then get, like,
this ombré effect,
and I loved it.
Your first look was
one of my favorites, for sure.
And then you had this
long-sleeve with all the ties.
I felt like it was something
that...
you know, lots of girls
who want to bring
that, like, cool streetwear
but also want that femininity,
you brought it to life.
It’s flirty.
-There’s romanticism in that.
-Yeah, it was romantic,
but it was, like, cool.
-ZAC: Cool romantic.
-Cool girl.
For me, it was
a very strong collection.
I think you’re
incredibly talented.
But in terms of a presentation
of a runway show,
it was a little bit
more challenging just because
I really was missing variation
of fabrication,
and I started to not
have the same kind of excitement
about your experimentation
with shape.
I do have to agree with Zac,
because I do love
your collection, but...
everything is in
the same fabric.
Either you need to give us,
like, a solid,
or you have to flip-flop
the fabric
so that something else happens.
My favorite designers, like,
when I see their 60-look
collections,
it’s like ten looks
all the same fabrication,
then ten more looks all...
like, it switches,
and that’s just my
kind of personal taste.
With ten looks,
you have to present a show
that is interesting
and cohesive but yet different.
And that’s very hard to do.
But the one thing
I do have to say
is that you have
signature details
that we know
the clothes are yours.
The oversize loops, the bands,
these proportions.
That’s Brandon, and I do think
that is very important.
All in all,
I think you have been
an incredibly gifted designer
that have given
all of your peers
a run for their money
and still are.
-Thank you. -Liris, how did you
feel on the runway today?
As a plus model, we don’t get
many opportunities
to actually be
at New York Fashion Week,
so I value every walk
down that runway very much.
Well, I think things
are all about to change.
-You’re leading the way. You’re
representing. -HEIDI: Yes.
-Oh, gosh, please.
-It’s really powerful.
Thank you. This is
something that my community
has wanted for a very long time.
This model diversity moment
means so much,
and I thank you all for being
a catalyst for change.
-Thank you, Liris.
-Thanks.
Thank you, Brandon.
Thank you, models.
-You can leave the runway.
-Thanks.
Ayana, why should you be
the winner of Project Runway?
My intention is to be
an industry leader
for the modest market,
and I really feel
very ready to take that on,
and, you know,
winning Project Runway would
make all that a reality for me.
-Margarita.
-I believe I have
a bit of an edge business-wise,
so I believe I could give
the greatest return
on your investment.
And I believe I could
really create a long-term career
with this head start.
-Kentaro.
-I think winning Project Runway
will give me more chances
to talk about my stories,
and I want to share my stories
with a lot of people.
-And Brandon.
-I kind of got an interesting
perspective and point of view,
and I am very certain
of the clothes I want to make,
and this obviously would be a...
a huge help
in launching my brand, and...
I just feel it’s time.
I feel I’m ready.
Okay, we’ve heard
what you had to say.
We have a big decision to make.
And then we will determine
who will be the winner
of Project Runway.
Now you can leave the runway.
Thank you.
-Thank you.
-Thank you.
HEIDI: The winner
of Project Runway will receive
the opportunity to collaborate
with JCPenney
on a limited edition
capsule collection
as part
of the Project Runway line sold
at select JCPenney stores
and online at JCP.com;
a selection of Brother sewing
and embroidery machines,
with a retail value of $40,000;
makeup and beauty products
for a year, courtesy of Avon;
the new 2018 Lexus NX,
coming this fall
with advanced innovation
and safety system standard;
from the Pilot FriXion
Erasable Pen,
the official pen
of Project Runway,
a lifetime supply of pens;
an all-expense-paid luxury trip
to Japan,
including a five-star stay
near Japan’s fashion center;
$100,000 to launch their line;
and the winning designer
and model will receive
a fashion spread
in Marie Claire magazine.
Wow, you guys. We have a very
big decision to make today.
-ZAC: Huge. -But it was
a fabulous runway show.
They each had
a different strong voice,
and I think they all
ex*cuted their vision
to the best I’ve seen yet
on the show.
I-I’m pretty blown away.
Our four finalists--
I have to say,
they’re really close.
Well, they all have
something individual.
Which makes things not easier.
I wish we could give it
to them all.
How do you choose?
-It’s hard.
-It’s hard.
[sighs]
All right, so...
-we made our decision?
-ZAC: Yeah.
♪ ♪
Are we sure?
-We’re sure.
-Okay.
Let’s bring them back out.
Well, all of you put on
a great show, but as you know,
only one of you
will be the winner
of Project Runway season 16.
Designers, the collection
that you showed us
for New York Fashion Week
blew us away.
We’re very, very proud.
Margarita,
from beginning to end,
your collection was 100% you.
You also truly embraced
your models’ curves
and celebrated each woman
individually.
Margarita...
I’m sorry. You’re out.
Thank you.
But you did a fantastic job.
Thank you for the opportunity.
Auf Wiedersehen.
MARGARITA:
Having shown
at New York Fashion Week,
I can say I’m
super proud of what I’ve done.
But I’m kind of bummed
’cause I did think
for a quick minute
that I could possibly win.
Hi, guys.
[laughter]
-Surprise!
-We made it, honey.
-We made it, we made it.
-Oh, I’m so happy.
MARGARITA:
That was the real prize,
was seeing my family
at the lounge.
-You did good. You did great.
-I love you so much.
Love you, too. Love you, too.
Told you we’d get here.
I just want to make
my family proud,
so mission accomplished.
-You did good. You did great.
-Thank you for coming.
-She looks fabulous.
-She was great, yeah?
♪ ♪
Brandon, your collection
was as unique as you are.
Your silhouettes
and your techniques
are inspirational.
Brandon...
I’m sorry. You’re out.
Auf Wiedersehen.
Mwah.
-All the best to you.
-Thank you. Thank you so much.
Thank you for the opportunity.
I appreciate it, guys.
It-it hurts.
[sniffles] Mm...
I thought I had it.
[sniffling]
[crying]
Aw!
BRANDON:
I guess I...
I really wanted it,
you know, uh...
I accomplished one goal
for sure, and that was to show
my womenswear at New York
Fashion Week, so...
got to pat myself on the back
for that one.
I’m so proud of you.
Sorry.
You should be so proud
of yourself.
Thank you.
♪ ♪
Ayana, your collection
had a great rhythm,
and it finished beautifully.
Your finale dress was one
of the most breathtaking looks
that we’ve ever seen.
Thank you.
Kentaro,
you really surprised us today.
We loved the emotion
and the unexpected designs
that you created,
and your clothes--
they really stood up
for themselves.
Ayana, Kentaro,
one of you will be the winner
of Project Runway season 16.
Kentaro...
You are the winner
of Project Runway season 16.
Congratulations.
[Heidi chuckles, sighs]
Thank you.
Thank you so much.
Ayana, I’m so sorry.
-That means you’re out.
-Thank you so much.
-It was very tough.
-You did a great job.
-Thank you, Heidi. Thank you.
-Auf Wiedersehen.
Congratulations.
AYANA: Overall,
I’m really, really happy
with everything,
and I feel like I did
my absolute best.
Whoa. [chuckles]
I didn’t win.
[sighs]
-But I was close.
-[sighs]
Just a couple months ago,
Project Runway was just
a dream for me, and not only
did I make it on,
but I made it so far.
I made... I was right there.
I’m happy.
I’m grateful for all of this.
I have to come up there
and give our winner a hug.
-Congratulations.
-Thank you. Thank you.
-Mwah. Mwah.
-Thank you, Heidi.
Yay! I just won Project Runway.
At the end,
I decided to take a risk,
and I won,
so I cannot believe it.
Kentaro, I am
unbelievably proud of you.
Today, you knocked it
out of the park.
-Congratulations.
-Thank you.
Throughout all these weeks,
I have seen you really
work hard, be very determined,
and then finally surprise us.
-Congratulations.
-Thank you.
I am just thrilled to see
such a talent come to life,
and how you express yourself,
it’s really beautiful.
-Thank you so much.
-HEIDI: I mean, you’ve been
great throughout
the whole season,
but today you really showed
what an artist you truly are.
Thank you.
Well, there are some people here
that want to come out
and congratulate you,
so come on out, guys.
[gasping]
-Oh, no.
-HEIDI: Oi. Gosh, oh, gosh.
Are you okay?
Oh, no. Come around.
Oh, my gosh.
Don’t go down here. Come here.
[quiet laughter]
-It was beautiful. Yes!
-That’s good!
KENTARO:
Winning Project Runway is...
like a dream come true.
Probably, I’m going to have
a little more opportunity,
but...
I’ll just keep myself humble
and work hard
and do my best.
♪ ♪
HEIDI:
Next time on Project Runway...
TIM:
Welcome to the Project Runway
season 16 reunion special.
-Wah!
-[laughter]
TIM: All 16 designers reunite,
clear up some issues...
Why would you bring something
that was against the rules?
-Come on. Things happen.
-...voice their opinions...
I thought it was
completely inhumane.
-It’s called integrity.
-...and settle their disputes
once and for all.
I don’t think
you’re telling the truth.
CLAIRE:
That entire situation for me
-was a blur.
-AMY: You know the truth.
You either tell the truth
or you don’t.
HEIDI: Visit myLifetime.com
to learn more
about the fashion you’ve seen
on tonight’s show.
Welcome to our World! Where we serve you cookies to ensure you get the best viewing experience on our site.
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
Did you know that you can remove censorship board-wide, use our advanced search functions, be notified when new content is posted, join our memberships, set episodes to show in any order you want & more if you are logged into your account?
Register or sign in here: ucp.php?mode=register
16x15 - Finale: Part 2
Watch/Buy Amazon
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.
Contestants compete with each other to create the best clothes and are restricted by time, materials and theme.